﻿using System;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Media;

namespace YesNoYesNoEtc
{
    public partial class Page : UserControl
    {
        static readonly TimeSpan DURATION = TimeSpan.FromSeconds(3);
        const bool AUTOREVERSE = true;

        PointCollection yesPoints, noPoints, interPoints;
        DateTime dateTimeStart;

        public Page()
        {
            InitializeComponent();

            yesPoints = Resources["yesPts"] as PointCollection;
            noPoints = Resources["noPts"] as PointCollection;
            interPoints = new PointCollection();
            dateTimeStart = DateTime.Now;

            CompositionTarget.Rendering += OnRendering;
        }

        void OnRendering(object sender, EventArgs args)
        {
            long elapsedTicks = (DateTime.Now - dateTimeStart).Ticks;
            long durationTicks = DURATION.Ticks + (AUTOREVERSE ? DURATION.Ticks : 0);
            double fraction = (elapsedTicks % durationTicks) / (double)durationTicks;

            if (AUTOREVERSE)
                fraction = 2 * (fraction < 0.5 ? fraction : 1 - fraction);

            polyline.Points = null;
            Interpolate(yesPoints, noPoints, interPoints, fraction);
            polyline.Points = interPoints;
        }

        void Interpolate(PointCollection in1, PointCollection in2, PointCollection res, double fraction)
        {
            res.Clear();

            for (int i = 0; i < in1.Count; i++)
            {
                res.Add(new Point((1 - fraction) * in1[i].X + fraction * in2[i].X,
                                  (1 - fraction) * in1[i].Y + fraction * in2[i].Y));
            }
        }
    }
}
